Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(703)

Unified Diff: sky/examples/widgets/spinning_mixed.dart

Issue 1175423007: Create an example app that demonstrates interactive coordination of an fn tree and a raw RenderObje… (Closed) Base URL: https://github.com/domokit/mojo.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sky/examples/widgets/spinning_mixed.dart
diff --git a/sky/examples/widgets/spinning_mixed.dart b/sky/examples/widgets/spinning_mixed.dart
index b76a09a0bc1aafeee5946727f217188c894f50c1..1a29927a47df3bc72eb4206bc4e0cc1fab5c715f 100644
--- a/sky/examples/widgets/spinning_mixed.dart
+++ b/sky/examples/widgets/spinning_mixed.dart
@@ -76,16 +76,16 @@ void rotate(double timeStamp) {
void main() {
// Because we're going to use UINodes, we want to initialise its
// AppView, not use the default one. We don't really need to do
// this, because RenderObjectToUINodeAdapter does it for us, but
// it's good practice in case we happen to not have a
// RenderObjectToUINodeAdapter in our tree at startup, or in case we
// want a renderViewOverride.
UINodeAppView.initUINodeAppView();
RenderFlex flexRoot = new RenderFlex(direction: FlexDirection.vertical);
RenderProxyBox proxy = new RenderProxyBox();
- new RenderObjectToUINodeAdapter(proxy, builder); // adds itself to proxy
+ new RenderBoxToUINodeAdapter(proxy, builder); // adds itself to proxy
addFlexChildSolidColor(flexRoot, const sky.Color(0xFFFF00FF), flex: 1);
flexRoot.add(proxy);
@@ -76,16 +76,16 @@ void rotate(double timeStamp) {
// Because we're going to use UINodes, we want to initialise its
// AppView, not use the default one. We don't really need to do
- // this, because RenderObjectToUINodeAdapter does it for us, but
+ // this, because RenderBoxToUINodeAdapter does it for us, but
// it's good practice in case we happen to not have a
@@ -76,16 +76,16 @@ void rotate(double timeStamp) {
// it's good practice in case we happen to not have a
- // RenderObjectToUINodeAdapter in our tree at startup, or in case we
+ // RenderBoxToUINodeAdapter in our tree at startup, or in case we
// want a renderViewOverride.
UINodeAppView.initUINodeAppView();

Powered by Google App Engine
This is Rietveld 408576698